PositionInfo class

Parsed position info from a GetPositionInfo SOAP response.

Constructors

PositionInfo({required Duration position, required Duration duration})
Creates a PositionInfo.
const

Properties

duration Duration
Total media duration.
final
hashCode int
The hash code for this object.
no setterinherited
position Duration
Current playback position.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited